@@ -1,6 +1,4 @@
 """Types and abstract base classes for metrics."""
-from __future__ import annotations
-
 import typing
 
 import astroid
@@ -16,8 +14,6 @@ class MetricResult(typing.Protocol):
         ...  # pragma: no cover
 
 
-N = typing.TypeVar("N", bound=astroid.nodes.NodeNG)
-R = typing.TypeVar("R", bound=MetricResult)
-Metric = typing.Callable[[N], R]
-IterMetric = typing.Callable[[typing.Iterable[N]], R]
-MethodMetric = typing.Callable[[astroid.FunctionDef], R]
+Metric = typing.Callable[[astroid.nodes.NodeNG], MetricResult]
+IterMetric = typing.Callable[[typing.Iterable[astroid.nodes.NodeNG]], MetricResult]
+MethodMetric = typing.Callable[[astroid.FunctionDef], MetricResult]
